<?php

namespace DMG\AI_Tools;

/**
 * Add the DMG Gutenberg AI Assistant
 *
 * Class Assistant
 *
 * @package DMG\AI_Tools
 */
class Assistant {

	/**
	 * Assistant constructor
	 */
	function __construct() {
		if ( get_option( 'dmg_ai_tools_url' ) && get_option( 'dmg_ai_tools_token' ) && get_option( 'dmg_ai_tools_system' ) ) {
			add_action( 'init', [ $this, 'register_block' ] );
			add_action( 'enqueue_block_editor_assets', [ $this, 'add_inline_js' ] );
		}
	}

	/**
	 * Register the new gutenberg block
	 */
	function register_block() {
		if ( \current_user_can( Init::CAPABILITY ) ) {
			register_block_type( __DIR__ . '/build' );
		}
	}

	/**
	 * Local JS vars for the block
	 */
	function add_inline_js() {
		$taxonomy_name = apply_filters( 'dmg_ai_tools_taxonomy_name', 'post_tag' );
		$term_slug = apply_filters( 'dmg_ai_tools_term_slug', 'ai-rewrite' );

		$ai_powered         = get_term_by( 'slug', 	$term_slug, $taxonomy_name );
		$ai_powered_term_id = is_a( $ai_powered, 'WP_Term' ) ? $ai_powered->term_id : false;

		$params = array(
			'system_message'           => get_option( 'dmg_ai_tools_system' ),
			'rewrite_prompt'           => get_option( 'dmg_ai_rewrite_prompt' ),
			'language'                 => get_option( 'dmg_ai_tools_language' ),
			'temperature'              => get_option( 'dmg_ai_tools_temperature' ),
			'top_p'                    => get_option( 'dmg_ai_tools_top_p' ),
			'frequency_penalty'        => get_option( 'dmg_ai_tools_frequency_penalty' ),
			'presence_penalty'         => get_option( 'dmg_ai_tools_presence_penalty' ),
			'max_tokens'               => get_option( 'dmg_ai_tools_max_tokens' ),
			'p_words_length'           => get_option( 'dmg_ai_tools_paragraph_length' ),
			'is_advanced'              => current_user_can( Init::ADVANCED_CAPABILITY ),
			'ai_powered_taxonomy_name' => $taxonomy_name,
			'ai_powered_term_id'       => $ai_powered_term_id
		);

		// Create a provisional adverts and enqueue ads config
		wp_add_inline_script(
			'dmg-ai-tools-editor-script',
			sprintf( 'var AIToolsOptions = %s', wp_json_encode( $params ) ),
			'before'
		);
	}

}

new Assistant();
