<?php

namespace DMG\AI_Tools;

/**
 * Register REST API endpoints to handle remote request to the AI service
 *
 * Class Rest_API
 *
 * @package DMG\AI_Tools
 */
class Rest_API {


	/**
	 * Namespace within wp-json
	 *
	 * @var string
	 */
	const NAMESPACE = 'dmg-ai-tools';

	/**
	 * Rest_API constructor
	 */
	function __construct() {
		add_action( 'rest_api_init', array( __CLASS__, 'register_endpoints' ) );
	}

	/**
	 * Register rest routes within the namespace
	 *
	 * @example https://example.com/wp-json/dmg_ai/
	 *
	 */
	public static function register_endpoints() {

		register_rest_route(
			self::NAMESPACE,
			'/ask',
			[
				'methods'             => \WP_REST_Server::CREATABLE,
				'callback'            => [ __CLASS__, 'post_callback' ],
				'permission_callback' => [ __CLASS__, 'permissions_check' ],
			]
		);
	}


	/**
	 * Handle the remote request
	 *
	 * @param $request
	 *
	 * @return mixed|\WP_Error|\WP_REST_Response
	 */
	public static function post_callback( $request ) {
		$params = $request->get_params();

		unset( $params['_locale'] );

		$response = wp_safe_remote_post(
			get_option( 'dmg_ai_tools_url' ),
			array(
				'headers'  => array(
					'Content-Type' => 'application/json',
					'api-key'      => get_option( 'dmg_ai_tools_token' ),
				),
				'body'     => json_encode( $params ),
				'blocking' => true,
				'timeout'  => 60
			)
		);

		if ( is_wp_error($response) ) {
			$response_body = [ "error" => [ "message" => $response->get_error_message() ] ];
			$response_status = 500;
		} else {
			$response_body = json_decode( wp_remote_retrieve_body( $response ) ) ;
			$response_status = wp_remote_retrieve_response_code( $response );
		}

		$rest_response = rest_ensure_response( $response_body );
		$rest_response->set_status( $response_status );

		return $rest_response;

	}

	/**
	 * Handle permissions
	 *
	 * @return bool
	 */
	public static function permissions_check() {
		return current_user_can( apply_filters( 'dmg_ai_tools_rest_api_cap', 'edit_posts' ) );
	}
}

new REST_API();
