import {dispatch, withSelect} from "@wordpress/data";
import {compose} from "@wordpress/compose";
import {registerPlugin} from "@wordpress/plugins";
import {PluginPrePublishPanel} from "@wordpress/edit-post";

// Prevent publish/update post if the dmg/ai-tools is present in the content
const postSaveRules = ({ blocks }) => {
	const lockName = 'dmgAILock';
	const message = "Please complete the AI rewriting in order to save the post.";

	if ( blocks.some( ( block) => { return block.name === 'dmg/ai-tools'  } ) ) {

		dispatch( 'core/editor' ).lockPostSaving(lockName);
		return (
				<PluginPrePublishPanel title="dmg ai tools" initialOpen={true} >
				<div class="components-notice is-error">
				<div class="components-notice__content">
				<p>{message}</p>
				</div>
				</div>
				</PluginPrePublishPanel>
			);
	} else {
		dispatch( 'core/editor' ).unlockPostSaving(lockName);
		return null;
	}

};

const dmgAiToolsRules = compose(
	withSelect((select) => ({
		blocks: select('core/block-editor').getBlocks(),
	}))
)(postSaveRules);

registerPlugin('dmg-ai-tools-rules', {render: dmgAiToolsRules});
